##  Hide Applications Outside the Defined Timeline
Enterprises often deal with large volumes of data, and their application landscapes constantly evolve, with applications being deprecated, replaced, and introduced. As the number of Fact Sheets grows, it becomes increasingly challenging to gain a clear understanding of what's happening on a roadmap report.
To address this challenge and enhance clarity, a toggle feature is available under the Settings section. This toggle lets you streamline your roadmap view by hiding Fact Sheets whose lifecycle falls outside the defined timeline.
You can enable or disable the Hide Fact Sheets not in timeline toggle in the Settings section of a Roadmap Report. Enabling the toggle hides Fact Sheets whose lifecycles do not intersect with the defined timeline, providing a more concise view of relevant information.
![](https://help.sap.com/doc/72d375467c1e4dcb872dfa2998b6328d/CLOUD/en-US/loio274e8d087a44101492d8e365a42544d9_LowRes.png)
When enabled:
  * Fact Sheets that are hidden due to the toggle setting are not lost.
  * A new banner, similar to the one used in the Matrix Report, displays a list of hidden Fact Sheets for easy access.
